@@ -1771,9 +1771,10 @@ static void dtInsertEntry(dtpage_t * p,	/* directory page */
 		lh->inumber = data->leaf.ino;
 		lh->namlen = klen;
 		name = lh->name;
-		if ((sb_ptr->s_flag & JFS_DIR_INDEX) == JFS_DIR_INDEX)
+		if ((sb_ptr->s_flag & JFS_DIR_INDEX) == JFS_DIR_INDEX) {
 			len = MIN(klen, DTLHDRDATALEN);
-		else
+			lh->index = 0;	/* Until we create index properly */
+		} else
 			len = MIN(klen, DTLHDRDATALEN_LEGACY);
 	} else {
 		ih = (struct idtentry *) h;
