@@ -1758,6 +1758,9 @@ int validate_dir_data(struct dinode *inoptr, uint32_t inoidx,
 	if (dxd_ptr->flag == 0)
 		goto out;
 
+	/* Work around bug that used to clear the DXD_INDEX bit */
+	dxd_ptr->flag |= DXD_INDEX;
+
 	/*
 	 * to be valid, it has to be a B-tree node,
 	 * either root-leaf or root-internal
@@ -2017,7 +2020,7 @@ int validate_EA(struct dinode *inoptr, uint32_t inoidx,
 			vea_rc =
 			    jfs_ValidateFEAList((struct FEALIST *)
 						&(inoptr->di_inlineea),
-						&eafmt_error);
+						dxd_ptr->size, &eafmt_error);
 			if ((vea_rc != FSCK_OK) || (eafmt_error != 0)) {
 				/* ea format is bad */
 				ea_format_bad = -1;
@@ -2090,9 +2093,9 @@ int validate_EA(struct dinode *inoptr, uint32_t inoidx,
 			goto out;
 		}
 		/* the ea has been read into the regular buffer */
-		vea_rc =
-		    jfs_ValidateFEAList((struct FEALIST *) agg_recptr->
-					ea_buf_ptr, &eafmt_error);
+		vea_rc = jfs_ValidateFEAList((struct FEALIST *)
+					     agg_recptr->ea_buf_ptr,
+					     dxd_ptr->size, &eafmt_error);
 		if ((vea_rc != FSCK_OK) || (eafmt_error != 0)) {
 			/* ea format is bad */
 			ea_format_bad = -1;
