@@ -1512,9 +1512,8 @@ int initial_processing(int argc, char **argv)
 		case MSG_JFS_VOLUME_IS_MOUNTED:
 			if (agg_recptr->parm_options[UFS_CHKDSK_LEVEL0]) {
 				/* read only */
-				printf("\n%s is currently mounted.\njfs_fsck "
-				       "will continue READ ONLY check.\n\n",
-				       Vol_Label);
+				fsck_send_msg(fsck_FSMNTD);
+				fsck_send_msg(fsck_MNTFSYS2);
 			} else {
 				/* is mounted */
 				printf("\n%s is mounted.\n\nWARNING!!!\n"
@@ -1689,18 +1688,6 @@ int initial_processing(int argc, char **argv)
 			agg_recptr->corrections_approved = 1;
 		}
 	}
-	/*
-	 * give the caller some information
-	 */
-	if ((agg_recptr->aggregate_is_mounted) &&
-#ifdef CLEARBADBLOCK
-	    (!agg_recptr->parm_options[UFS_CHKDSK_CLRBDBLKLST]) &&
-#endif
-	    (agg_recptr->processing_readonly)) {
-		/* agg is mounted */
-		fsck_send_msg(fsck_FSMNTD);
-		fsck_send_msg(fsck_MNTFSYS2);
-	}
 	if ((!agg_recptr->parm_options[UFS_CHKDSK_LEVEL0]) && 
 	    (agg_recptr->processing_readonly)) {
 		/* user did not specify check only but we can only
@@ -1971,12 +1958,11 @@ int phase0_processing()
 			ujfs_get_superblk(Dev_IOPort, sb_ptr, 1);
 		}
 	}
-	if ( (agg_recptr->parm_options[UFS_CHKDSK_IFDIRTY] &&
+	if (agg_recptr->parm_options[UFS_CHKDSK_IFDIRTY] &&
 	    (!agg_recptr->parm_options_nologredo) &&
 	    ((sb_ptr->s_state & FM_DIRTY) != FM_DIRTY)
 	     && (agg_recptr->logredo_rc == FSCK_OK)
-	    && ((sb_ptr->s_flag & JFS_BAD_SAIT) != JFS_BAD_SAIT)) ||
-	    agg_recptr->parm_options_logredo_only ) {
+	    && ((sb_ptr->s_flag & JFS_BAD_SAIT) != JFS_BAD_SAIT)) {
 		/*
 		 * user specified 'only if dirty'
 		 * and didn't specify 'omit logredo()'
@@ -1985,6 +1971,15 @@ int phase0_processing()
 		 */
 		agg_recptr->fsck_is_done = 1;
 		exit_value = FSCK_OK;
+	} else if (agg_recptr->parm_options_logredo_only) {
+		/*
+		 * User only wants to run logredo, no matter what.
+		 * Make sure we leave a dirty superblock marked dirty
+		 */
+		if (sb_ptr->s_state & FM_DIRTY)
+			agg_recptr->ag_dirty = 1;
+		agg_recptr->fsck_is_done = 1;
+		exit_value = FSCK_OK;
 	}
 	/*
 	 * if things look ok so far, make storage allocated by logredo()
