@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000
+ *   Copyright (c) International Business Machines Corp., 2000-2002
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 #include <jfs_types.h>
 #include "devices.h"
 
-int32_t ujfs_rwinode(HFILE, struct dinode *, uint32_t, int32_t, int32_t, uint32_t, uint32_t);
-int32_t ujfs_rwdaddr(HFILE, int64_t *, struct dinode *, int64_t, int32_t, int32_t);
+int ujfs_rwinode(HFILE, struct dinode *, uint32_t, int32_t, int32_t, uint32_t, uint32_t);
+int ujfs_rwdaddr(HFILE, int64_t *, struct dinode *, int64_t, int32_t, int32_t);
 
 #endif
