@@ -25,6 +25,7 @@
 #include <stdlib.h>
 #include <memory.h>
 #include <string.h>
+#include <errno.h>
 #include "jfs_endian.h"
 #include "jfs_filsys.h"
 #include "jfs_superblock.h"
@@ -38,7 +39,7 @@
 #include "devices.h"
 #include "debug.h"
 
-#include "fsckmsgc.h"		/* for fsck message logging facility */
+#include "fsck_message.h"		/* for fsck message logging facility */
 
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
   *
@@ -46,24 +47,8 @@
   *
   *      defined in xchkdsk.c
   */
-extern char message_parm_0[];
-extern char message_parm_1[];
-extern char message_parm_2[];
-extern char message_parm_3[];
-extern char message_parm_4[];
-extern char message_parm_5[];
-extern char message_parm_6[];
-extern char message_parm_7[];
-extern char message_parm_8[];
-extern char message_parm_9[];
-
-extern char *msgprms[];
-extern int16_t msgprmidx[];
-
 extern char *verbose_msg_ptr;
 
-extern char *MsgText[];
-
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
   *
   *    R E M E M B E R    M E M O R Y    A L L O C    F A I L U R E
@@ -215,14 +200,12 @@ signed char budtab[256] = {
 /*
  * external references
  */
-extern int errno;
 extern int fsError(int, int, int64_t);
 extern int markBmap(struct dmap *, pxd_t, int, int);
 extern int bflush(int32_t, struct bufpool *);
 extern int alloc_storage(int32_t, void **, int32_t *);
 extern int alloc_dmap_bitrec(struct dmap_bitmaps **);
 
-extern void fsck_send_msg(int, int);
 extern int alloc_wrksp(uint32_t, int, int, void **);
 
 /*
@@ -273,10 +256,7 @@ int initMaps(int32_t vol)
 	PXDaddress(&pxd1, AITBL_OFF >> vopen[vol].l2bsize);
 	PXDlength(&pxd1, vopen[vol].lbperpage);
 	if ((rc = bread(vol, pxd1, (void **) &dip, PB_READ)) != 0) {
-		sprintf(message_parm_0, "(d) %d", errno);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_READBMAPINOFAIL, 1);
+		fsck_send_msg(lrdo_READBMAPINOFAIL, errno);
 		return (BREAD_BMAPINIT);
 	}
 
@@ -285,7 +265,7 @@ int initMaps(int32_t vol)
 
 	/* read block map into memory and init workmap to zeros */
 	if ((rc = bMapInit(vol, dip)) != 0) {
-		fsck_send_msg(lrdo_READBMAPFAIL, 0);
+		fsck_send_msg(lrdo_READBMAPFAIL);
 		return (rc);
 	}
 
@@ -295,10 +275,7 @@ int initMaps(int32_t vol)
 	/* read in the fileset imap inode (i_number = 16) in a buffer: */
 	PXDaddress(&pxd1, (AITBL_OFF + (SIZE_OF_MAP_PAGE << 1)) >> vopen[vol].l2bsize);
 	if ((rc = bread(vol, pxd1, (void **) &dip, PB_READ)) != 0) {
-		sprintf(message_parm_0, "(d) %d", errno);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_READIMAPINOFAIL, 1);
+		fsck_send_msg(lrdo_READIMAPINOFAIL, errno);
 		return (BREAD_IMAPINIT);
 	}
 
@@ -307,7 +284,7 @@ int initMaps(int32_t vol)
 
 	/* read inode map into memory and init workmap to zeros */
 	if ((rc = iMapInit(vol, dip)) != 0) {
-		fsck_send_msg(lrdo_READIMAPFAIL, 0);
+		fsck_send_msg(lrdo_READIMAPFAIL);
 		return (rc);
 	}
 	/* Return 0 */
@@ -365,7 +342,7 @@ int bMapInit(int vol,		/* index in vopen array */
 	     struct dinode *dip)
 {				/* disk inode of bmap */
 	int bmi_rc = 0;
-	int32_t ndmaps, nl0pages = 0, nl1pages = 0;
+	int32_t ndmaps;
 	int I_am_logredo = -1;
 	uint32_t bytes_needed = 0;
 	caddr_t p0 = NULL;
@@ -393,15 +370,8 @@ int bMapInit(int vol,		/* index in vopen array */
 	bytes_needed = (6 * PSIZE) + (vopen[vol].bmap_page_count * sizeof (struct bmap_wsp));
 
 	ndmaps = ((vopen[vol].fssize + BPERDMAP - 1) >> L2BPERDMAP);
-	nl0pages = (ndmaps + LPERCTL - 1) / LPERCTL;
-	if (nl0pages > 1) {
-		nl1pages = (nl0pages + LPERCTL - 1) / LPERCTL;
-	}
 
-	sprintf(message_parm_0, "(d) %d", bytes_needed);
-	msgprms[0] = message_parm_0;
-	msgprmidx[0] = 0;
-	fsck_send_msg(lrdo_ALLOC4BMAP, 1);
+	fsck_send_msg(lrdo_ALLOC4BMAP, bytes_needed);
 
 	bmi_rc = alloc_wrksp((uint32_t) bytes_needed, 0, I_am_logredo, (void **) &p0);
 	/*
@@ -415,10 +385,7 @@ int bMapInit(int vol,		/* index in vopen array */
 		bmap_stg_addr = p0;
 		bmap_stg_bytes = bytes_needed;
 	} else {
-		sprintf(message_parm_0, "(d) %lld", (long long) __le64_to_cpu(dip->di_size));
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_ALLOC4BMAPFAIL, 1);
+		fsck_send_msg(lrdo_ALLOC4BMAPFAIL, (long long) __le64_to_cpu(dip->di_size));
 		Insuff_memory_for_maps = -1;
 		return (0);
 	}
@@ -457,7 +424,7 @@ int bMapInit(int vol,		/* index in vopen array */
 	 * block allocation map xtree
 	 */
 	if (rXtree(vol, dip, &xp)) {
-		fsck_send_msg(lrdo_RBMPREADXTFAIL, 0);
+		fsck_send_msg(lrdo_RBMPREADXTFAIL);
 		return (BMAP_READERROR1);
 	}
 
@@ -495,7 +462,7 @@ int bMapInit(int vol,		/* index in vopen array */
 		if (xaddr) {
 			PXDaddress(&pxd, xaddr);
 			if (bread(vol, pxd, (void **) &xp, PB_READ)) {
-				fsck_send_msg(lrdo_RBMPREADNXTLFFAIL, 0);
+				fsck_send_msg(lrdo_RBMPREADNXTLFFAIL);
 				return (BMAP_READERROR3);
 			}
 		}
@@ -568,7 +535,7 @@ int bMapRead(int vol,		/* index in vopen array */
 				    vopen[vol].bmap_wsp[page_number].
 				    page_offset, PSIZE, page_buffer, GET);
 	if (bmr_rc != 0) {
-		fsck_send_msg(lrdo_RBMPREADDATFAIL, 0);
+		fsck_send_msg(lrdo_RBMPREADDATFAIL);
 		return (BMAP_READERROR7);
 	}
 
@@ -597,11 +564,8 @@ int bMapWrite(int vol,		/* index in vopen array */
 				    vopen[vol].bmap_wsp[page_number].
 				    page_offset, PSIZE, page_buffer, PUT);
 	if (bmw_rc != 0) {
-		sprintf(message_parm_0, "0x0%llx",
-			(long long) vopen[vol].bmap_wsp[page_number].page_offset);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_WRBMPBLKWRITEFAIL, 1);
+		fsck_send_msg(lrdo_WRBMPBLKWRITEFAIL,
+			      (long long)vopen[vol].bmap_wsp[page_number].page_offset);
 		return (BMAP_WRITEERROR2);
 	}
 
@@ -730,22 +694,16 @@ int iMapInit(int vol,		/* index in vopen array */
 	 * of PSIZE so we don't have to round it up.
 	 * di_size is number of bytes
 	 */
-	sprintf(message_parm_0, "(d) %d", bytes_needed);
-	msgprms[0] = message_parm_0;
-	msgprmidx[0] = 0;
-	fsck_send_msg(lrdo_ALLOC4IMAP, 1);
+	fsck_send_msg(lrdo_ALLOC4IMAP, bytes_needed);
 
 	imi_rc = alloc_storage((uint32_t) bytes_needed, (void **) &ptr0, &allocated_from_bmap);
 
 	if ((imi_rc != 0) || (ptr0 == NULL)) {	/* imap allocation failed */
-		sprintf(message_parm_0, "(d) %d", bytes_needed);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_ALLOC4IMAPFAIL, 1);
+		fsck_send_msg(lrdo_ALLOC4IMAPFAIL, bytes_needed);
 		return (ENOMEM2);
 	} else if (ptr0 != NULL) {	/* imap allocation successful */
 		if (allocated_from_bmap) {
-			fsck_send_msg(lrdo_USINGBMAPALLOC4IMAP, 0);
+			fsck_send_msg(lrdo_USINGBMAPALLOC4IMAP);
 		}
 	}
 
@@ -776,7 +734,7 @@ int iMapInit(int vol,		/* index in vopen array */
 	 * which have the xad's for the map data
 	 */
 	if (rXtree(vol, dp, &p)) {
-		fsck_send_msg(lrdo_RIMPREADXTFAIL, 0);
+		fsck_send_msg(lrdo_RIMPREADXTFAIL);
 		return (IMAP_READERROR1);
 	}
 
@@ -789,7 +747,7 @@ int iMapInit(int vol,		/* index in vopen array */
 	 * inode allocation map xtree
 	 */
 	if (rXtree(vol, dp, &p)) {
-		fsck_send_msg(lrdo_RIMPREADXTFAIL, 0);
+		fsck_send_msg(lrdo_RIMPREADXTFAIL);
 		return (IMAP_READERROR2);
 	}
 
@@ -828,7 +786,7 @@ int iMapInit(int vol,		/* index in vopen array */
 		if (xaddr) {
 			PXDaddress(&pxd, xaddr);
 			if (bread(vol, pxd, (void **) &p, PB_READ)) {
-				fsck_send_msg(lrdo_RIMPREADNXTLFFAIL, 0);
+				fsck_send_msg(lrdo_RIMPREADNXTLFFAIL);
 				return (IMAP_READERROR3);
 			}
 		}
@@ -868,7 +826,7 @@ int iMapRead(int vol,		/* index in vopen array */
 				    vopen[vol].fsimap_lst.imap_wsp[page_number].page_offset, 
 				    PSIZE, page_buffer, GET);
 	if (imr_rc != 0) {
-		fsck_send_msg(lrdo_RIMPREADDATFAIL, 0);
+		fsck_send_msg(lrdo_RIMPREADDATFAIL);
 		return (IMAP_READERROR4);
 	}
 
@@ -897,11 +855,8 @@ int iMapWrite(int vol,		/* index in vopen array */
 				    vopen[vol].fsimap_lst.imap_wsp[page_number].page_offset, 
 				    PSIZE, page_buffer, PUT);
 	if (imw_rc != 0) {
-		sprintf(message_parm_0, "0x0%llx",
-			(long long) vopen[vol].bmap_wsp[page_number].page_offset);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_WRIMPBLKWRITEFAIL, 1);
+		fsck_send_msg(lrdo_WRIMPBLKWRITEFAIL,
+			      (long long)vopen[vol].bmap_wsp[page_number].page_offset);
 		return (IMAP_WRITEERROR2);
 	}
 
@@ -943,22 +898,16 @@ int iagGet(int vol,		/* index in vopen array */
 	 * allocate and set up a data workspace for this page
 	 */
 	bytes_needed = sizeof (struct iag_data);
-	sprintf(message_parm_0, "(d) %d", bytes_needed);
-	msgprms[0] = message_parm_0;
-	msgprmidx[0] = 0;
-	fsck_send_msg(lrdo_ALLOC4IMAP, 1);
+	fsck_send_msg(lrdo_ALLOC4IMAP, bytes_needed);
 	ig_rc = alloc_storage((uint32_t) bytes_needed,
 			      (void **) &iag_datarec, &allocated_from_bmap);
 
 	if ((ig_rc != 0) || (iag_datarec == NULL)) {
-		sprintf(message_parm_0, "(d) %d", bytes_needed);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_ALLOC4IMAPFAIL, 1);
+		fsck_send_msg(lrdo_ALLOC4IMAPFAIL, bytes_needed);
 		return (ENOMEM2);
 	}
 	if (allocated_from_bmap) {
-		fsck_send_msg(lrdo_USINGBMAPALLOC4IMAP, 0);
+		fsck_send_msg(lrdo_USINGBMAPALLOC4IMAP);
 	}
 	iag_pg = vopen[vol].fsimap_lst.iag_pbuf;
 	maplen = sizeof (uint32_t) * LPERDMAP;
@@ -992,7 +941,7 @@ int updateMaps(int32_t vol)
 	PXDaddress(&pxd1, (AITBL_OFF + (SIZE_OF_MAP_PAGE << 1)) >> vopen[vol].l2bsize);
 	PXDlength(&pxd1, vopen[vol].lbperpage);
 	if ((rc = bread(vol, pxd1, (void **) &dip, PB_READ)) != 0) {
-		fsck_send_msg(lrdo_UMPREADIMAPINOFAIL, 0);
+		fsck_send_msg(lrdo_UMPREADIMAPINOFAIL);
 		return (IMAP_READERROR5);
 	}
 
@@ -1001,7 +950,7 @@ int updateMaps(int32_t vol)
 
 	/* finalize the imap and write it out */
 	if ((rc = writeImap(vol, vopen[vol].fsimap_lst, dip)) != 0) {
-		fsck_send_msg(lrdo_UMPWRITEIMAPCTLFAIL, 0);
+		fsck_send_msg(lrdo_UMPWRITEIMAPCTLFAIL);
 		return (rc);
 	}
 
@@ -1015,7 +964,7 @@ int updateMaps(int32_t vol)
 		/* read in the bmap inode (i_number = 2) in a buffer: */
 		PXDaddress(&pxd1, AITBL_OFF >> vopen[vol].l2bsize);
 		if ((rc = bread(vol, pxd1, (void **) &dip, PB_READ)) != 0) {
-			fsck_send_msg(lrdo_UMPREADBMAPINOFAIL, 0);
+			fsck_send_msg(lrdo_UMPREADBMAPINOFAIL);
 			return (BMAP_READERROR4);
 		}
 
@@ -1024,7 +973,7 @@ int updateMaps(int32_t vol)
 
 		/* finalize the bmap and write it out */
 		if ((rc = writeBmap(vol, vopen[vol].bmap_ctl, dip)) != 0) {
-			fsck_send_msg(lrdo_UMPWRITEBMAPCTLFAIL, 0);
+			fsck_send_msg(lrdo_UMPWRITEBMAPCTLFAIL);
 		}
 	}
 	/* end we do have a local BMap image */
@@ -1054,11 +1003,11 @@ int writeImap(int vol,		/* index in vopen array */
 	int32_t maplen, inoext_arrlen;
 
 	if (vopen[vol].status == FM_LOGREDO) {
-		fsck_send_msg(lrdo_WRIMPNOTRBLDGIMAP, 0);
+		fsck_send_msg(lrdo_WRIMPNOTRBLDGIMAP);
 		return (NOTREBUILDING_IMAP);
 	}
 
-	fsck_send_msg(lrdo_WRIMPSTART, 0);
+	fsck_send_msg(lrdo_WRIMPSTART);
 
 	imap_ctl = fsimap.fsimapctrl;
 	iagp = fsimap.iag_pbuf;
@@ -1225,7 +1174,7 @@ int writeImap(int vol,		/* index in vopen array */
 		return (rc);
 	}
 
-	fsck_send_msg(lrdo_WRIMPDONE, 0);
+	fsck_send_msg(lrdo_WRIMPDONE);
 
 	return (0);
 }
@@ -1246,7 +1195,6 @@ int updateImapPage(int32_t vol,	/* index in vopen array  */
 	uint i, sword, mask;
 	uint16_t allfree;
 	uint8_t *cp;
-	uint64_t pxdaddr;
 
 	/* copy the perm map to the work map. */
 	p->nfreeinos = 0;
@@ -1267,7 +1215,7 @@ int updateImapPage(int32_t vol,	/* index in vopen array  */
 			 * At the logredo time, we have to null out the
 			 * address of p->inoext[i] if p->pmap[i] is zero.
 			 */
-			if ((pxdaddr = addressPXD(&p->inoext[i])) != 0) {
+			if (addressPXD(&p->inoext[i]) != 0) {
 				rc = markBmap((struct dmap *) vopen[vol].
 					      bmap_ctl, p->inoext[i], 0, vol);
 				if (rc != 0) {
@@ -1286,7 +1234,7 @@ int updateImapPage(int32_t vol,	/* index in vopen array  */
 				p->extsmap[sword] |= mask;
 				*numinos += INOSPEREXT;
 			} else
-				fsck_send_msg(lrdo_RBLDGIMAPERROR2, 0);
+				fsck_send_msg(lrdo_RBLDGIMAPERROR2);
 		} else if (~p->pmap[i] && (addressPXD(&p->inoext[i]) != 0)) {
 			/* there is some bits are zeroes */
 			p->extsmap[sword] |= mask;
@@ -1296,7 +1244,7 @@ int updateImapPage(int32_t vol,	/* index in vopen array  */
 			p->nfreeinos += (maptab[*cp] + maptab[*(cp + 1)]
 					 + maptab[*(cp + 2)] + maptab[*(cp + 3)]);
 		} else
-			fsck_send_msg(lrdo_RBLDGIMAPERROR1, 0);
+			fsck_send_msg(lrdo_RBLDGIMAPERROR1);
 	}
 
 	if (allfree == EXTSPERIAG)
@@ -1334,11 +1282,11 @@ int writeBmap(int32_t vol,	/* index in vopen array */
 	int32_t bitmaplen;
 
 	if (vopen[vol].status == FM_LOGREDO) {
-		fsck_send_msg(lrdo_WRBMPNOTRBLDGBMAP, 0);
+		fsck_send_msg(lrdo_WRBMPNOTRBLDGBMAP);
 		return (NOTREBUILDING_BMAP);
 	}
 
-	fsck_send_msg(lrdo_WRBMPSTART, 0);
+	fsck_send_msg(lrdo_WRBMPSTART);
 
 	/*
 	 * set the pointers to the corresponding page buffers
@@ -1362,7 +1310,7 @@ int writeBmap(int32_t vol,	/* index in vopen array */
 	npages = BLKTODMAPN(h_fssize - 1) + 1;
 
 	if (npages > (__le64_to_cpu(dip->di_size) >> L2PSIZE)) {
-		fsck_send_msg(lrdo_WRBMPBADMAPSIZE, 0);
+		fsck_send_msg(lrdo_WRBMPBADMAPSIZE);
 		return (BMAP_WRITEERROR1);
 	}
 
@@ -1432,16 +1380,8 @@ int writeBmap(int32_t vol,	/* index in vopen array */
 			vopen[vol].L0_pagenum = next_bmap_page;
 			next_bmap_page++;
 			if (l0ptr->leafidx != CTLLEAFIND) {
-				sprintf(message_parm_0, "(d) %d", k);
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = 0;
-				sprintf(message_parm_1, "(d) %d", j);
-				msgprms[1] = message_parm_1;
-				msgprmidx[1] = 0;
-				sprintf(message_parm_2, "(d) %d", l0ptr->leafidx);
-				msgprms[2] = message_parm_2;
-				msgprmidx[2] = 0;
-				fsck_send_msg(lrdo_WRBMPBADLFIDX0, 3);
+				fsck_send_msg(lrdo_WRBMPBADLFIDX0, k, j,
+					      l0ptr->leafidx);
 				return ILLEGAL_LEAF_IND0;
 			}
 			l0leaf = l0ptr->stree + l0ptr->leafidx;
@@ -1478,16 +1418,7 @@ int writeBmap(int32_t vol,	/* index in vopen array */
 				n = MIN(nblocks, BPERDMAP);
 				rc = updDmapPage(dmap, n, l0leaf);
 				if (rc != 0) {
-					sprintf(message_parm_0, "(d) %d", k);
-					msgprms[0] = message_parm_0;
-					msgprmidx[0] = 0;
-					sprintf(message_parm_1, "(d) %d", j);
-					msgprms[1] = message_parm_1;
-					msgprmidx[1] = 0;
-					sprintf(message_parm_2, "(d) %d", i);
-					msgprms[2] = message_parm_2;
-					msgprmidx[2] = 0;
-					fsck_send_msg(lrdo_RBLDGDMAPERROR, 3);
+					fsck_send_msg(lrdo_RBLDGDMAPERROR, k, j, i);
 					return (DMAP_UPDATEFAIL);
 				}
 
@@ -1675,7 +1606,7 @@ int writeBmap(int32_t vol,	/* index in vopen array */
 		return (rc);
 	}
 
-	fsck_send_msg(lrdo_WRBMPDONE, 0);
+	fsck_send_msg(lrdo_WRBMPDONE);
 
 	return (0);
 }
@@ -1719,7 +1650,7 @@ int updDmapPage(struct dmap *p0,	/* pointer to this struct dmap page */
 	p0->nfree = 0;		/* init nfree field */
 
 	if ((int32_t) (tp->leafidx) != (int32_t) (LEAFIND)) {
-		fsck_send_msg(lrdo_UPDMPBADLFIDX, 0);
+		fsck_send_msg(lrdo_UPDMPBADLFIDX);
 		return ILLEGAL_LEAF_IND1;
 	}
 	cp = tp->stree + tp->leafidx;	/*cp points to first leaf of dmap tree */
@@ -1753,7 +1684,6 @@ int rXtree(int32_t vol,		/* index in vopen array */
 	   struct dinode *dp,	/* disk inode of map    */
 	   xtpage_t ** first_leaf)
 {				/* pointer to first leaf page of map xtree */
-	int rc;
 	xtpage_t *p;
 	caddr_t buf_ptr;
 	pxd_t pxd;
@@ -1773,8 +1703,8 @@ int rXtree(int32_t vol,		/* index in vopen array */
 	 */
 	do {
 		/* read in the leftmost child page */
-		if ((rc = bread(vol, pxd, (void **) &buf_ptr, PB_READ)) != 0) {
-			fsck_send_msg(lrdo_RXTREADLFFAIL, 0);
+		if (bread(vol, pxd, (void **) &buf_ptr, PB_READ) != 0) {
+			fsck_send_msg(lrdo_RXTREADLFFAIL);
 			return (MINOR_ERROR);
 		}
 
@@ -1954,10 +1884,7 @@ int bread(int32_t vol,		/* index in vopen (minor of aggregate)  */
 	blkno = addressPXD(&pxd);
 	if (vopen[vol].bmap_ctl != NULL && (blkno + nblocks) > vopen[vol].fssize) {
 		fsError(DBTYPE, vol, blkno);
-		sprintf(message_parm_0, "0x0%llx", (long long) blkno);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_BRDBADBLOCK, 1);
+		fsck_send_msg(lrdo_BRDBADBLOCK, (long long) blkno);
 		return (MINOR_ERROR);
 	}
 
@@ -2041,10 +1968,7 @@ int bread(int32_t vol,		/* index in vopen (minor of aggregate)  */
 				(unsigned) nbytes, (char *) &buffer[k - 1], GET);
 	if (rc != 0) {
 		fsError(IOERROR, vol, blkno);
-		sprintf(message_parm_0, "0x0%llx", (long long) blkno);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_BRDREADBLKFAIL, 1);
+		fsck_send_msg(lrdo_BRDREADBLKFAIL, (long long) blkno);
 		return (MINOR_ERROR);
 	}
 
