@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000
+ *   Copyright (c) International Business Machines Corp., 2000-2002
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -14,13 +14,6 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program;  if not, write to the Free Software 
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- *   MODULE_NAME:		inodes.h
- *
- *   COMPONENT_NAME: 	jfsformat
- *
- *   FUNCTIONS: 	none
- *
  */
 #ifndef H_INODES
 #define H_INODES
@@ -29,11 +22,11 @@
 
 typedef enum { inline_data, extent_data, max_extent_data, no_data } ino_data_type;
 
-int32_t init_aggr_inode_table(int32_t, HFILE, struct dinode *, int32_t, int64_t, int64_t, int32_t, uint32_t);
-int32_t init_fileset_inode_table(int32_t, HFILE, int64_t *, int32_t *, int64_t, int64_t, uint32_t);
-int32_t init_fileset_inodes(int32_t, HFILE, int64_t, int32_t, int64_t, uint32_t);
+int init_aggr_inode_table(int, HFILE, struct dinode *, int, int64_t, int64_t, int, unsigned);
+int init_fileset_inode_table(int, HFILE, int64_t *, int *, int64_t, int64_t, unsigned);
+int init_fileset_inodes(int, HFILE, int64_t, int, int64_t, unsigned);
 
-void init_inode(struct dinode *, int32_t, uint32_t, int64_t, int64_t, int64_t, mode_t,
-		        ino_data_type, int64_t, int32_t, uint32_t);
+void init_inode(struct dinode *, int, unsigned, int64_t, int64_t, int64_t, mode_t,
+		ino_data_type, int64_t, int, unsigned);
 
 #endif
