@@ -501,7 +501,7 @@ static int create_aggregate(int dev_ptr,
 		if (stat(logdev, &st))
 			return errno;
 
-		aggr_superblock.s_logdev = dev_to_kdev(st.st_rdev);
+		aggr_superblock.s_logdev = st.st_rdev;
 		memset(&aggr_superblock.s_logpxd, 0, sizeof (pxd_t));
 		uuid_copy(aggr_superblock.s_loguuid, log_uuid);
 	} else {
@@ -591,13 +591,14 @@ void parse_journal_opts(const char *opts, int *ext_journal_opt,
 	int journal_usage = 0;
 	int log_fd = -1;
 	uuid_t log_uuid;
+	int in_use;
 
 	/*
 	 * -J device= means we're going to attach an existing
 	 * external journal to a newly formatted file system
 	 */
 	if (strncmp(opts, "device=", 7) == 0) {
-		LogOpenMode = O_RDWR | O_EXCL;
+		LogOpenMode = O_RDONLY;
 		/* see if device is specified by UUID */
 		if (strncmp(opts + 7, "UUID=", 5) == 0) {
 			if (uuid_parse((char *) opts + 7 + 5, log_uuid)) {
@@ -607,7 +608,7 @@ void parse_journal_opts(const char *opts, int *ext_journal_opt,
 			} else {
 				log_fd =
 				    open_by_label(log_uuid, 0, 1,
-						  journal_device);
+						  journal_device, &in_use);
 				/*
 				 * If successful, open_by_label returns a file 
 				 * descriptor to an open file.  For jfs_mkfs 
@@ -627,7 +628,7 @@ void parse_journal_opts(const char *opts, int *ext_journal_opt,
 		} else if (strncmp(opts + 7, "LABEL=", 6) == 0) {
 			log_fd =
 			    open_by_label((char *) opts + 7 + 6, 1, 1,
-					  journal_device);
+					  journal_device, &in_use);
 			/*
 			 * If successful, open_by_label returns a file descriptor
 			 * to an open file.  For jfs_mkfs purposes, we do not yet
@@ -957,7 +958,7 @@ int main(int argc, char *argv[])
 
 		/* A log device was specified on the command line.  Call 
 		   * jfs_logform() to initialize the log */
-		fd = open(logdev, O_RDWR | O_EXCL, 0);
+		fd = open(logdev, LogOpenMode, 0);
 		if (fd < 0) {
 			message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, OSO_MSG);
 			close(dev_handle);
